@@ -1,4 +1,4 @@
-/* $Id$ */
+/* vi:set et ai sw=2 sts=2 ts=2: */
 /*-
  * Copyright (c) 2005 Benedikt Meurer <benny@xfce.org>
  *
@@ -39,7 +39,9 @@ typedef enum
 {
   THUNAR_UCA_MODEL_COLUMN_NAME,
   THUNAR_UCA_MODEL_COLUMN_DESCRIPTION,
-  THUNAR_UCA_MODEL_COLUMN_ICON,
+  THUNAR_UCA_MODEL_COLUMN_GICON,
+  THUNAR_UCA_MODEL_COLUMN_ICON_NAME,
+  THUNAR_UCA_MODEL_COLUMN_UNIQUE_ID,
   THUNAR_UCA_MODEL_COLUMN_COMMAND,
   THUNAR_UCA_MODEL_COLUMN_STARTUP_NOTIFY,
   THUNAR_UCA_MODEL_COLUMN_PATTERNS,
@@ -88,12 +90,15 @@ void            thunar_uca_model_remove         (ThunarUcaModel         *uca_mod
 void            thunar_uca_model_update         (ThunarUcaModel         *uca_model,
                                                  GtkTreeIter            *iter,
                                                  const gchar            *name,
+                                                 const gchar            *unique_id,
                                                  const gchar            *description,
                                                  const gchar            *icon,
                                                  const gchar            *command,
                                                  gboolean                startup_notify,
                                                  const gchar            *patterns,
-                                                 ThunarUcaTypes          types);
+                                                 ThunarUcaTypes          types,
+                                                 guint                   accel_key,
+                                                 GdkModifierType         accel_mods);
 
 gboolean        thunar_uca_model_save           (ThunarUcaModel         *uca_model,
                                                  GError                **error);
