@@ -208,7 +208,8 @@ struct _ThunarApplication
 
   GList                 *files_to_launch;
 
-  guint                  dbus_owner_id;
+  guint                  dbus_owner_id_xfce;
+  guint                  dbus_owner_id_fdo;
 };
 
 
@@ -324,14 +325,23 @@ thunar_application_dbus_init (ThunarApplication *application)
     if (geteuid() == 0)
       return;
 
-    application->dbus_owner_id = g_bus_own_name (G_BUS_TYPE_SESSION,
-                               "org.xfce.FileManager",
-                               G_BUS_NAME_OWNER_FLAGS_NONE,
-                               thunar_application_dbus_acquired_cb,
-                               thunar_application_name_acquired_cb,
-                               thunar_application_dbus_name_lost_cb,
-                               application,
-                               NULL);
+    application->dbus_owner_id_xfce = g_bus_own_name (G_BUS_TYPE_SESSION,
+                                      "org.xfce.FileManager",
+                                      G_BUS_NAME_OWNER_FLAGS_NONE,
+                                      thunar_application_dbus_acquired_cb,
+                                      thunar_application_name_acquired_cb,
+                                      thunar_application_dbus_name_lost_cb,
+                                      application,
+                                      NULL);
+
+    application->dbus_owner_id_fdo = g_bus_own_name (G_BUS_TYPE_SESSION,
+                                     "org.freedesktop.FileManager1",
+                                     G_BUS_NAME_OWNER_FLAGS_NONE,
+                                     thunar_application_dbus_acquired_cb,
+                                     thunar_application_name_acquired_cb,
+                                     thunar_application_dbus_name_lost_cb,
+                                     application,
+                                     NULL);
 }
 
 
@@ -359,13 +369,13 @@ thunar_application_startup (GApplication *gapp)
                     G_CALLBACK (thunar_application_uevent), application);
 #endif
 
-  /* connect to the session manager */
-  application->session_client = thunar_session_client_new (opt_sm_client_id);
-
   thunar_application_dbus_init (application);
 
   G_APPLICATION_CLASS (thunar_application_parent_class)->startup (gapp);
 
+  /* connect to the session manager */
+  application->session_client = thunar_session_client_new (opt_sm_client_id);
+
   /* TODO: how do accel maps integrate with GAction/GMenu? Using GtkAction for now */
   /* check if we have a saved accel map */
   path = xfce_resource_lookup (XFCE_RESOURCE_CONFIG, ACCEL_MAP_PATH);
@@ -1104,6 +1114,11 @@ thunar_application_quit (ThunarApplication *application)
   _thunar_return_if_fail (THUNAR_IS_APPLICATION (application));
 
   thunar_application_set_daemon(application, FALSE);
+
+  /* For some unknown reason we need to close all open thunar windows before quit */
+  /* Otherwise thunar will hangup on quit and thunar_application_shutdown will not be called */
+  thunar_application_close_all_windows (application);
+
   gtk_main_quit ();
 }
 
@@ -1153,6 +1168,28 @@ thunar_application_set_daemon (ThunarApplication *application,
 
 
 
+/**
+ * thunar_application_close_all_windows:
+ * @application : a #ThunarApplication.
+ *
+ * Closes all #ThunarWindows currently handled by @application.
+ **/
+void
+thunar_application_close_all_windows (ThunarApplication *application)
+{
+  GList *gtk_windows, *lp;
+
+  _thunar_return_if_fail (THUNAR_IS_APPLICATION (application));
+
+  gtk_windows = gtk_application_get_windows (GTK_APPLICATION (application));
+
+  for (lp = gtk_windows; lp != NULL; lp = lp->next)
+    if (G_LIKELY (THUNAR_IS_WINDOW (lp->data)))
+      gtk_window_close (lp->data);
+}
+
+
+
 /**
  * thunar_application_get_windows:
  * @application : a #ThunarApplication.
